Extensions to xarray (:mod:`erlab.accessors`)
=============================================

.. automodule:: erlab.accessors


   .. rubric:: Classes

   .. autosummary::

      PlotAccessor
      ImageToolAccessor
      SelectionAccessor
      MomentumAccessor


